<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- eigene Variablen_________________________________________ -->
	<xsl:variable name="freeline">3pt</xsl:variable>
	<xsl:variable name="pagewidth"><xsl:value-of select="//pageWidth"/></xsl:variable>
	<xsl:variable name="pageheight"><xsl:value-of select="//pageHeight"/></xsl:variable>
	<xsl:variable name="right"><xsl:value-of select="//marginRight"/></xsl:variable>
	<xsl:variable name="left"><xsl:value-of select="//marginLeft"/></xsl:variable>
	<xsl:variable name="bottom"><xsl:value-of select="//marginBottom"/></xsl:variable>
	<xsl:variable name="top"><xsl:value-of select="//marginTop"/></xsl:variable>
	<xsl:variable name="masse"><xsl:value-of select="//masse"/></xsl:variable>
	<xsl:variable name="normBreite">
		<xsl:value-of select="($pagewidth -$left -$right)"/>
	</xsl:variable>
	<!-- Start Template /_____________________________________________- -->
	<xsl:template match="/">
		<!-- _______________________________R O O T___________________- -->
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<!--______________________________________ defines page layout -->
			<fo:layout-master-set>
				<!-- layout for the first page -->
				<fo:simple-page-master master-name="only">
					<xsl:attribute name="page-width"><xsl:value-of select="$pagewidth"/><xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="page-height"><xsl:value-of select="$pageheight"/><xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-left"><xsl:value-of select="$left"/><xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-right"><xsl:value-of select="$right"/><xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-top"><xsl:value-of select="$top"/><xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-bottom"><xsl:value-of select="$bottom"/><xsl:value-of select="$masse"/></xsl:attribute>
					<fo:region-body margin-top="1.2cm"/>
					<fo:region-before precedence="true" extent="2cm"/>
					<fo:region-after precedence="true" extent="1.5cm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<!-- end: defines page layout _________________________________________-->
			<!-- actual layout ___________________________________________________-->
			<fo:page-sequence master-reference="only" initial-page-number="1">
				<!-- usage of page layout -->
				<!-- ************************************ HEADER *********************-->
				<fo:static-content flow-name="xsl-region-before">
					<fo:block text-align="end" font-size="8pt" font-family="Helvetica">
						Ausfall- und Wartezeiten pro Kostenstelle <xsl:value-of select="//Statistik/Zeitraum"></xsl:value-of>
						Seite:  <fo:page-number/> / <fo:page-number-citation ref-id="endofdoc"/>
					</fo:block>
					<xsl:if test="page-number&gt;1">
						<fo:block font-family="Helvetica" font-size="10pt">
							<!--xsl:call-template name="SeitenKopf"/-->
							<xsl:apply-templates select="//Statistik/titel"/>
						</fo:block>
					</xsl:if>
				</fo:static-content>
				<!-- ************************************ BODY ************************-->
				<fo:flow flow-name="xsl-region-body">
					<fo:block font-family="Helvetica" font-size="10.0pt">
						<xsl:call-template name="SeitenKopf"/>
						<xsl:apply-templates select="//Statistik/titel"/>
					</fo:block>
					<fo:block font-family="Helvetica" font-size="8pt" text-align="start">
						<xsl:apply-templates select="//Statistik"/>
						<fo:block id="endofdoc"/>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für SeitenKopf-->
	<!-- *******************************************************-->
	<!-- *******************************************************-->
	<!--Template  für   Eigenfertigung  Statistik-->
	<!-- *******************************************************-->
	<xsl:template match="titel">
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(0.8)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>

			<fo:table-header background-color="lightgray" display-align="center">
				<fo:table-row>
					<xsl:for-each select="//Statistik/titel/*">

						<fo:table-cell border-bottom-style="solid" border-bottom-width="1pt">
						
							<xsl:if test="position()=5">	
							<fo:block font-size="7pt" padding-top="2pt" text-align="end">
								<xsl:value-of select="."/>
							</fo:block>
							</xsl:if>
							<xsl:if test="position()=4">	
							<fo:block font-size="7pt" padding-top="2pt" text-align="end">
								<xsl:if test="name(.)='key' and .='MM/JJ'">MM.JJJJ</xsl:if>
							</fo:block>
							</xsl:if>
							<xsl:if test="position()=1 or position()=2 or position()=3">	
							<fo:block font-size="7pt" padding-top="2pt" text-align="start">
								<xsl:value-of select="."/>
							</fo:block>
							</xsl:if>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>	
			</fo:table-body>
		</fo:table>	
		
	</xsl:template>
<!-- *******************************************************-->
	<!-- *******************************************************-->

	<xsl:template name="SeitenKopf">
		<fo:block>
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
															<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(46)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(0.1)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(0.1)"/>
				<fo:table-body>
				<!--fo:table-row height="20pt">
						<fo:table-cell>
							
						</fo:table-cell>
						<fo:table-cell>
							
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="end">
								<fo:inline>
									Stand v. <xsl:value-of select="//Statistik/datum"/>
						
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="end">
								<fo:inline>
									Seite:  <fo:page-number/> / <fo:page-number-citation ref-id="endofdoc"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row-->

				
				
					<fo:table-row>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt">
							<fo:block text-align="start">
								
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt" number-columns-spanned="3">
							<fo:block>
								<fo:inline text-align="start" font-family="Helvetica" font-size="12pt" font-weight="bold">
								Ausfall- und Wartezeiten pro Kostenstelle   
									<fo:inline font-size="11pt"> Zeitraum: </fo:inline>
                                                              <xsl:value-of select="//Statistik/Zeitraum"/>  
								</fo:inline>
								
								    <!--Zeitraum: <fo:inline text-align="start" font-family="Helvetica" font-size="12pt" font-weight="bold">

								<xsl:value-of select="//data/vonDatum"/> - <xsl:value-of select="//data/bisDatum"/>
								</fo:inline-->

							</fo:block>
						</fo:table-cell>
						
						
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>
	
	<!-- *******************************************************-->
	<!--Template  für    Statistik - Abteilung-->
	<!-- *******************************************************-->
		<xsl:template match="Statistik">	
		
		<xsl:apply-templates select="./Abteilung"/>
		<xsl:call-template name="return"/>
<xsl:call-template name="return"/>
		<xsl:apply-templates select="./SummeGesamt"/>
		
		</xsl:template>
		
	<!-- *******************************************************-->
	<!--Template  für    Statistik - Abteilung-->
	<!-- *******************************************************-->
		<xsl:template match="Abteilung">	
		<fo:block font-size="10pt" font-weight="bold" font-family="Helvetica">
			<xsl:value-of select="./BlockTitel"/>:
		</fo:block>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			
			<fo:table-column column-number="1" column-width="proportional-column-width(0.8)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>
			
			<fo:table-body>
			
			<xsl:for-each select="./Kostenstelle">
			
				<xsl:for-each select="./Ausfallzeit">	
					<xsl:apply-templates select="./Ergebnis"/>
					<!--<xsl:apply-templates select="./SummeAusfallUndWartezeiten"/>-->
				</xsl:for-each><!--end Ausfallzeiten -->	
				
				<xsl:apply-templates select="SummeKostenstelle"/>
				
			</xsl:for-each><!--end Kostenstelle-->
			
			<xsl:apply-templates select="SummeAbteilung"/>	
					
			</fo:table-body>
		</fo:table>
		
		
		
		</xsl:template>
	
	<!-- *******************************************************-->
	<!--Template  für KOstensxstelle -->
	<!-- *******************************************************-->
	<xsl:template match="Ergebnis">
			<fo:table-row>
		<xsl:for-each select="*">
					<fo:table-cell padding-top="1pt" border-top="1pt solid gray">
						<xsl:if test="position()=4">	
							<fo:block font-size="9pt" text-align="end">
							<xsl:value-of select="."/>
						</fo:block>
							</xsl:if>	
							<xsl:if test="position()=5">	
							<fo:block font-size="10pt" text-align="end" font-family="Courier">
							<xsl:value-of select="."/>
						</fo:block>
							</xsl:if>	

							<xsl:if test="position()=1 or position()=2 or position()=3">	
							<fo:block font-size="9pt" text-align="start">
							<xsl:value-of select="."/>
						</fo:block>
							</xsl:if>
					</fo:table-cell>
					
</xsl:for-each>


			</fo:table-row>
		
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für KOstensxstelle -->
	<!-- *******************************************************-->
	<!--<xsl:template match="SummeAusfallUndWartezeiten">
					<fo:table-row><xsl:for-each select="*">

					<fo:table-cell padding-top="1pt" border-before-style="solid" border-before-width="1pt">
					
					<xsl:if test="position()=4 or position()=5">	
							<fo:block font-size="9pt" text-align="end">
							<xsl:value-of select="."/>
						</fo:block>
							</xsl:if>	
							<xsl:if test="position()=2 or position()=3">	
							<fo:block font-size="9pt" text-align="start">
							<xsl:value-of select="."/>
						</fo:block>
							</xsl:if>
							<xsl:if test="position()=1">	
							<fo:block font-size="9pt" text-align="start">
							Summe Ausf u.Wart.
						</fo:block>
							</xsl:if>
					</fo:table-cell>
					</xsl:for-each>
			</fo:table-row>
			</xsl:template>-->
<!-- *******************************************************-->
	<!--Template  für KOstensxstelle -->
	<!-- *******************************************************-->
	<xsl:template match="SummeKostenstelle">
		<fo:table-row>
			<xsl:for-each select="*">
			
			<xsl:if test="position()=1">
					<fo:table-cell padding-top="1pt" border-top="1pt solid black" border-bottom="1pt solid black" number-columns-spanned="4">

						<fo:block font-size="9pt" text-align="start" font-family="Helvetica">
								Summe KST
						</fo:block>
					</fo:table-cell>
			</xsl:if>
			<xsl:if test="position()>4">
			
					<fo:table-cell padding-top="1pt" border-top="1pt solid black" border-bottom="1pt solid black">
					
					<fo:block font-size="10pt" text-align="end" font-family="Courier">
							<xsl:value-of select="."/>
							</fo:block>
					
						</fo:table-cell>
			</xsl:if>
			</xsl:for-each>
		</fo:table-row>
		<fo:table-row height="7pt"/>
			
	</xsl:template>

	<!-- *******************************************************-->
	<!--Template -->
	<!-- *******************************************************-->
		<xsl:template match="BlockTitel">
			<xsl:value-of select="."/>		
		</xsl:template>
	
	
	<!-- *******************************************************-->
	<!--Template  für  tabelle-normal-plus-linie OBEN, row(last)-->
	<!--S P A N-->
	<!-- *******************************************************-->
	<xsl:template match="SummeAbteilung">
			
		<fo:table-row>
				<xsl:for-each select="*">
				<xsl:if test="position()=1">
					<fo:table-cell  number-columns-spanned="4"  padding-top="2pt" border-bottom="1pt solid black">
						<fo:block font-size="10pt" font-family="Helvetica" font-weight="bold">
								Summe  <xsl:value-of select="../../BlockTitel"/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>	
				

				<xsl:if test="position()>4">
					<fo:table-cell padding-top="2pt" border-bottom="1pt solid black">
						<fo:block text-align="end" font-size="10pt" font-weight="bold" font-family="Courier">
							<xsl:value-of select="."/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
		</xsl:for-each>
			</fo:table-row>
		<fo:table-row height="12pt"/>	
		
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für  tabelle-normal-plus-linie  Für SummeGesammt-->
	<!-- *******************************************************-->
	<xsl:template match="SummeGesamt">
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
									<xsl:value-of select="$masse"/></xsl:attribute>
			
			<fo:table-column column-number="1" column-width="proportional-column-width(0.8)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>

			
			<fo:table-header/>
			<fo:table-body>
				<fo:table-row>
					<xsl:for-each select="*">
					<xsl:if test="position()=1">
						<fo:table-cell number-columns-spanned="3" padding-top="5pt" 
												border-before-style="solid"
												 border-before-width="1pt" border-after-style="solid"
										 					 border-after-width="1pt">
							<fo:block font-size="11pt" font-weight="bold" font-family="Helvetica">	
							Summe Gesamt
					</fo:block>
				</fo:table-cell>
			</xsl:if>	
			<xsl:if test="position()>3">
					<fo:table-cell padding-top="5pt" border-before-style="solid" 
						border-before-width="1pt" border-after-style="solid" border-after-width="1pt">
						<fo:block text-align="end" font-size="11pt" font-weight="bold" font-family="Courier">
							<xsl:value-of select="."/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
			</xsl:for-each>
		</fo:table-row>
	</fo:table-body>
	<fo:table-footer/> 
	</fo:table>	
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für return-->
	<!-- *******************************************************-->
	<xsl:template name="return">
		<fo:block>
			<xsl:attribute name="space-before.optimum"><xsl:value-of select="$freeline"/></xsl:attribute>
		</fo:block>
	</xsl:template>
<!--#######################-->
<!--'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''-->	
</xsl:stylesheet>
