<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- eigene Variablen_________________________________________ -->
	<xsl:variable name="freeline">3pt</xsl:variable>
	<xsl:variable name="pagewidth"><xsl:value-of select="//pageWidth"/></xsl:variable>
	<xsl:variable name="pageheight"><xsl:value-of select="//pageHeight"/></xsl:variable>
	<xsl:variable name="right"><xsl:value-of select="//marginRight"/></xsl:variable>
	<xsl:variable name="left"><xsl:value-of select="//marginLeft"/></xsl:variable>
	<xsl:variable name="bottom"><xsl:value-of select="//marginBottom"/></xsl:variable>
	<xsl:variable name="top"><xsl:value-of select="//marginTop"/></xsl:variable>
	<xsl:variable name="masse"><xsl:value-of select="//masse"/></xsl:variable>
	<xsl:variable name="normBreite">
		<xsl:value-of select="($pagewidth -$left -$right)"/>
	</xsl:variable>
	<!-- Start Template /_____________________________________________- -->
	<xsl:template match="/">
		<!-- _______________________________R O O T___________________- -->
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<!--______________________________________ defines page layout -->
			<fo:layout-master-set>
				<!-- layout for the first page -->
				<fo:simple-page-master master-name="only">
					<xsl:attribute name="page-width"><xsl:value-of select="$pagewidth"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="page-height"><xsl:value-of select="$pageheight"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-left"><xsl:value-of select="$left"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-right"><xsl:value-of select="$right"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-top"><xsl:value-of select="$top"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-bottom"><xsl:value-of select="$bottom"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<fo:region-body margin-top="0.7cm"/>
					<fo:region-before precedence="true" extent="2cm"/>
					<fo:region-after precedence="true" extent="1.5cm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<!-- actual layout ______________________________________-->
			<fo:page-sequence master-reference="only" initial-page-number="1">
				<!-- usage of page layout -->
				<!-- ************************************ HEADER *********************-->
				<fo:static-content flow-name="xsl-region-before">
					<fo:block text-align="end" font-size="8pt" font-family="Helvetica">
						SOLL / IST Vergleich pro Kostenstelle und Position <xsl:value-of select="//Statistik/Zeitraum"></xsl:value-of>
						Seite:  <fo:page-number/> / <fo:page-number-citation ref-id="endofdoc"/>
					</fo:block>
				</fo:static-content>
				<!-- ************************************ BODY ************************-->
				<fo:flow flow-name="xsl-region-body">
					<fo:block font-family="Helvetica" font-size="10.0pt">
						<xsl:call-template name="SeitenKopf"/>
					</fo:block>
					<fo:block font-family="Courier" font-size="8pt" text-align="start">
						<xsl:apply-templates select="//Statistik/Abteilung"/>
						<xsl:apply-templates select="//Statistik/SummeGesamt"/>
						<fo:block id="endofdoc"/>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für SeitenKopf-->
	<!-- *******************************************************-->
	<xsl:template name="SeitenKopf">
		<fo:block>
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
					<xsl:value-of select="$masse"/>
				</xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(46)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(0.1)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(0.1)"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt"/>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt">
							<fo:block text-align="start" font-family="Helvetica" font-size="12pt" font-weight="bold">
									SOLL / IST Vergleich pro Kostenstelle und Position   
									<!--fo:inline font-family="Helvetica" font-size="11pt">Zeitraum: </fo:inline-->
									<xsl:value-of select="//Statistik/Zeitraum"></xsl:value-of>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt">
							<!--fo:block text-align="end" font-size="7pt">
									Stand v. <fo:inline font-size="9pt" font-weight="bold">
												<xsl:value-of select="//datum"/>
											</fo:inline>		
							</fo:block-->
						</fo:table-cell>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt">
							<!--fo:block text-align="end" font-size="7pt">
									Seite:  <fo:page-number/> / <fo:page-number-citation ref-id="endofdoc"/>
							</fo:block-->
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für   Eigenfertigung  Statistik-->
	<!-- *******************************************************-->
	<xsl:template match="Abteilung">
		<fo:block font-size="11pt" font-family="Helvetica" font-weight="bold" text-decoration="underline">
			<xsl:value-of select="./BlockTitel"/>:
		</fo:block>
		<xsl:apply-templates select="Kostenstelle"/>
		<xsl:apply-templates select="SummeAbteilung"/>
		<xsl:call-template name="return"/>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für  tabelle-normal-plus-linie OBEN, row(last)-->
	<!--S P A N-->
	<!-- *******************************************************-->
	<xsl:template match="SummeAbteilung">
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
														<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.01)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(0.01)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="9" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="10" column-width="proportional-column-width(1.3)"/>
				<fo:table-body>
					<fo:table-row>
						<xsl:for-each select="*">
							<xsl:if test="position()=1">
								<fo:table-cell padding-top="5pt" border-bottom="1pt solid black" border-top="1pt solid black" number-columns-spanned="4">
									<fo:block>
										<fo:inline font-size="11pt" font-family="Helvetica" font-weight="bold">
											Summe <xsl:apply-templates select="../../BlockTitel"/>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
                    	 			 </xsl:if>
							<xsl:if test="position()>3">
								<fo:table-cell padding-top="2pt" border-bottom="1pt solid black" border-top="1pt solid black">
									<fo:block text-align="end" font-size="10pt" font-weight="bold">
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
						</xsl:for-each>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block> </fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>		
		</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für return-->
	<!-- *******************************************************-->
	<xsl:template name="return">
		<fo:block>
			<xsl:attribute name="space-before.optimum"><xsl:value-of select="$freeline"/></xsl:attribute>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für KOstensxstelle -->
	<!-- *******************************************************-->
	<xsl:template match="Kostenstelle">
		<xsl:for-each select=".">
			<fo:block font-size="10pt" font-family="Helvetica" font-weight="bold">
				 <xsl:value-of select="./Position/Ergebnis/Kostenstelle"/> 
				<xsl:apply-templates select="./BlockTitel"/>						
			</fo:block>
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.01)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(0.01)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="9" column-width="proportional-column-width(1.8)"/>
				<fo:table-column column-number="10" column-width="proportional-column-width(1.3)"/>
				<fo:table-header background-color="lightgray" display-align="center">
					<fo:table-row>
						<xsl:for-each select="//Statistik/titel/*">
							<fo:table-cell border-bottom-style="solid" border-bottom-width="1.0pt">
								<fo:block font-size="7pt" padding-top="4pt" padding-after="3pt" font-family="Helvetica">		 
									<xsl:if test="position()=3">
										<xsl:attribute name="text-align">start</xsl:attribute>
									</xsl:if>
			 						<xsl:if test="position()>3">
										<xsl:attribute name="text-align">end</xsl:attribute>
									</xsl:if>
									<xsl:if test="name(.)='key' and .='KOST'"></xsl:if>
									<xsl:if test="name(.)='key' and .='KOST NAME'"></xsl:if>
									<xsl:if test="name(.)='key' and .='POSITION'">POSITION</xsl:if>
									<xsl:if test="name(.)='key' and .='MM/JJ'">MM/JJ</xsl:if>
									<xsl:if test="name(.)='key' and .='h/min IST'">h/min IST</xsl:if>
									<xsl:if test="name(.)='key' and .='h/min SOLL'">/ SOLL</xsl:if>
									<xsl:if test="name(.)='key' and .='EURO IST'">EUR  IST</xsl:if>
									<xsl:if test="name(.)='key' and .='EURO SOLL '">/ SOLL</xsl:if>
									<xsl:if test="name(.)='key' and .='ABW EURO'">Abw. EUR</xsl:if>
									<xsl:if test="name(.)='key' and .='ABW.%'">Abw.%</xsl:if>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="./Position">
						<!--xsl:apply-templates select="./Ergebnis"/-->
						<xsl:apply-templates select="./SummePosition"/>
					</xsl:for-each>
					<fo:table-row height="3pt">
						<fo:table-cell border-top="1pt solid lightgray" number-columns-spanned="10">
							<fo:block/>
						</fo:table-cell>
					</fo:table-row>
					<xsl:apply-templates select="./SummeKostenstelle"/>
					<fo:table-row height="2pt">
						<fo:table-cell number-columns-spanned="10">
							<fo:block/>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>		
		</xsl:for-each>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template -->
	<!-- *******************************************************-->
		<xsl:template match="BlockTitel">
			<xsl:value-of select="."/>	
		</xsl:template>
	<!-- *******************************************************-->
	<!--Template -->
	<!-- *******************************************************-->
	<xsl:template match="Ergebnis">
		<xsl:for-each select=".">
			<fo:table-row>
				<xsl:for-each select="./*">
					<fo:table-cell padding-top="1pt" border-top="1pt solid lightgray">
						<xsl:if test="position()=1 or position()=2">
							<fo:block></fo:block>
						</xsl:if>
						<xsl:if test="position()=3">
						<fo:block text-align="start" font-size="9pt">
							<xsl:value-of select="."/>
						</fo:block>
						</xsl:if>
						<xsl:if test="position()>3">
							<fo:block text-align="end" font-size="9pt">
								<xsl:value-of select="."/>
							</fo:block>
						</xsl:if>
					</fo:table-cell>
				</xsl:for-each>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template -->
	<!-- *******************************************************-->
	<xsl:template match="SummePosition">
		<xsl:for-each select=".">
			<fo:table-row>
				<xsl:for-each select="./*">
					<fo:table-cell padding-top="3pt" border-top="1pt solid lightgray">
						<xsl:if test="position()=1 or position()=2">
							<fo:block/>
						</xsl:if>
						<xsl:if test="position()=3">
							<fo:block text-align="start" font-size="9pt" font-weight="bold">
								Summe <xsl:value-of select="."/>
							</fo:block>
						</xsl:if>
						<xsl:if test="position()>4">
							<fo:block text-align="end" font-size="9pt" font-weight="bold">
								<xsl:value-of select="."/>
							</fo:block>
						</xsl:if>
					</fo:table-cell>
				</xsl:for-each>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template -->
	<!-- *******************************************************-->
	<xsl:template match="SummeKostenstelle">
		<fo:table-row>
			<xsl:for-each select="*">
				<xsl:if test="position()=1">
					<fo:table-cell padding-top="3pt" border-bottom="1pt solid black" border-top="1pt solid black" number-columns-spanned="4">
						<fo:block text-align="start" font-size="10pt" font-weight="bold">
							<fo:inline font-family="Helvetica">Summe <xsl:value-of select="../Kostenstelle"/> 
								<xsl:value-of select="../KostenstelleBezeichnung"/>
							</fo:inline>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
				<xsl:if test="position()>3">
					<fo:table-cell padding-top="3pt" border-bottom="1pt solid black" border-top="1pt solid black">
						<fo:block text-align="end" font-size="10pt" font-weight="bold">
							<xsl:value-of select="."/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
			</xsl:for-each>
		</fo:table-row>
		<fo:table-row height="1pt"/>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für  tabelle-normal-plus-linie  Für SummeGesammt-->
	<!-- *******************************************************-->
	<xsl:template match="SummeGesamt">
		<xsl:call-template name="return"/>
		<xsl:call-template name="return"/>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
									<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(0.01)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(0.01)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(2)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(1.5)"/>
			<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="6" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="7" column-width="proportional-column-width(1.8)"/>
			<fo:table-column column-number="8" column-width="proportional-column-width(1.8)"/>
			<fo:table-column column-number="9" column-width="proportional-column-width(1.8)"/>
			<fo:table-column column-number="10" column-width="proportional-column-width(1.3)"/>
				<fo:table-header/>
				<fo:table-body>
					<fo:table-row>
						<xsl:for-each select="*">
							<xsl:if test="position()=1">
								<fo:table-cell number-columns-spanned="4" padding-top="7pt" border-before-style="solid"
								 			border-before-width="1pt" border-after-style="solid" border-after-width="1pt">
									<fo:block font-size="11pt" font-weight="bold" font-family="Helvetica">
										<fo:character character="S" font-size="15pt"></fo:character>umme
										<fo:character character="G" font-size="15pt"></fo:character>esamt
									</fo:block>
								</fo:table-cell>
							</xsl:if>	
							<xsl:if test="position()>4">
								<fo:table-cell padding-top="7pt" border-before-style="solid" 
											border-before-width="1pt" border-after-style="solid" border-after-width="1pt">
									<fo:block text-align="end" font-size="10pt" font-weight="bold">
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-body>
				<fo:table-footer/> 
			</fo:table>	
	</xsl:template>
<!--#######################-->
<!--'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''-->	
</xsl:stylesheet>
