<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- eigene Variablen_________________________________________ -->
	<xsl:variable name="freeline">4pt</xsl:variable>
	<xsl:variable name="pagewidth">21</xsl:variable>
	<xsl:variable name="pageheight">29.5</xsl:variable>
	<xsl:variable name="right">1.5</xsl:variable>
	<xsl:variable name="left">2</xsl:variable>
	<xsl:variable name="bottom">1</xsl:variable>
	<xsl:variable name="top">1</xsl:variable>
	<xsl:variable name="masse">cm</xsl:variable>
	<xsl:variable name="normBreite">
		<xsl:value-of select="($pagewidth -$right -$left)"/>
	</xsl:variable>
	
	<!-- Start Template /_____________________________________________- -->
	<xsl:template match="/">
		<!-- _______________________________R O O T___________________- -->
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<!--______________________________________ defines page layout -->
			<fo:layout-master-set>
				<!-- layout for the first page -->
				<fo:simple-page-master master-name="only">
					<xsl:attribute name="page-width"><xsl:value-of select="$pagewidth"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="page-height"><xsl:value-of select="$pageheight"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-left"><xsl:value-of select="$left"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-right"><xsl:value-of select="$right"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-top"><xsl:value-of select="$top"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<xsl:attribute name="margin-bottom"><xsl:value-of select="$bottom"/>
					<xsl:value-of select="$masse"/></xsl:attribute>
					<fo:region-before precedence="true" extent="1cm"/>
					<fo:region-body margin-top="0.7cm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<!-- end: defines page layout _________________________________________-->
			<!-- actual layout ___________________________________________________-->
			<fo:page-sequence master-reference="only">
				<!-- usage of page layout -->
				<!-- ************************************ HEADER ********************************************-->
				<fo:static-content flow-name="xsl-region-before">
					<fo:block font-family="Helvetica" font-size="11.0pt">
						<xsl:call-template name="SeitenKopf"/>  
					</fo:block>
				</fo:static-content>
				<!-- ************************************ BODY ********************************************-->
				<fo:flow flow-name="xsl-region-body">
					<fo:block font-family="Helvetica" font-size="11.0pt" text-align="start">
						<xsl:apply-templates select="//Vorkalkulationsprotokoll/data"/>
						<xsl:apply-templates select="//Vorkalkulationsprotokoll/Auftrag"/>

						<xsl:apply-templates select="//Produktbeschreibung"/>
						  <xsl:apply-templates select="//Zuschussbogen"/>

						<xsl:apply-templates select="//Vorkalkulationsprotokoll/Komponente"/>
							<xsl:call-template name="make-line"/>
							<xsl:apply-templates select="//Vorkalkulationsprotokoll/Summen"/>
						<fo:block id="endofdoc"/>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
		<!-- ** FO END  ***********************************************   -->
	</xsl:template>
      <!-- *******************************************************-->
	<!--Template  für SeitenKopf-->
	<!-- *******************************************************-->
	<xsl:template name="SeitenKopf">
		<fo:block>
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
							<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(1.5)"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="0.5pt"
						 padding-left="0.5cm">
							<fo:block text-align="start">
								<fo:inline>
									<xsl:value-of select="//Vorkalkulationsprotokoll/data/auftragsnummer"/> 
									 <xsl:value-of select="//Vorkalkulationsprotokoll/SeitenKopf/Auftragsnummer"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-bottom="0.5pt solid black">
							<fo:block text-align="start" font-weight="bold">Vorkalkulationsprotokoll
									<!--<xsl:value-of select="//Vorkalkulationsprotokoll/data/titel"/>--> 
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="0.5pt" 
						padding-right="0.5cm">
							<fo:block text-align="end">
									<xsl:value-of select="./Datum"/>  
									Seite:  <fo:page-number/> / <fo:page-number-citation ref-id="endofdoc"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!-- *******************************************************-->
	
	<xsl:template match="data">
		<fo:table border-width="1pt" border-style="solid" padding-top="5pt"
		 padding-bottom="5pt" table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/><xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="*">
					<fo:table-row>
						<fo:table-cell padding-left="7pt">
								<fo:block>
								<xsl:if test="name(.)='kunde'">
									<fo:inline font-weight="bold"> Kunde:
									</fo:inline>
									<xsl:call-template name="return"/>
								</xsl:if>
								<xsl:if test="name(.)='auftragsnummer'">Auftragsnummer:</xsl:if>
								<xsl:if test="name(.)='titel'">Titel:</xsl:if>
								<xsl:if test="name(.)='besteller'">Besteller:</xsl:if>
								<xsl:if test="name(.)='bestellTyp'">Bestellt:</xsl:if>
								<xsl:if test="name(.)='bestellDatum'">Bestellt am:</xsl:if>
								<xsl:if test="name(.)='telefon'">Telefon:</xsl:if>
								<xsl:if test="name(.)='fax' and string-length(.)>0">Fax:</xsl:if>
								<xsl:if test="name(.)='sachbearbeiter'">Sachbearbeiter:</xsl:if>
								<xsl:if test="name(.)='auflage'">Auflage:</xsl:if>
								<xsl:if test="name(.)='preis'">Preis:</xsl:if>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
							<xsl:if test="name(.)='kunde'">
								<fo:block font-weight="bold">
									<xsl:value-of select="."/>
								</fo:block>
							</xsl:if>
							<xsl:if test="name(.)!='kunde'">
							<fo:block>
								<xsl:value-of select="."/>
							</fo:block>
							</xsl:if>

						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!--Template  für AuftragKopf-->
	<!-- *******************************************************-->
	<xsl:template match="Auftrag">
		<fo:table border-width="1pt" border-style="solid" padding-top="0.5cm"
		 padding-bottom="0.5cm" table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="*">
					<fo:table-row>
						<fo:table-cell padding-left="1cm">
							<fo:block text-align="start">
								<xsl:value-of select="name(.)"/>:
								<xsl:if test=" name(.)='Kunde'">
									<xsl:call-template name="return"/>
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding-right="3.5pt">
							<fo:block>
								<xsl:if test=" name(.)='Kunde'">
									<xsl:attribute name="font-weight">bold</xsl:attribute>
								</xsl:if>
								<xsl:value-of select="."/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Produktbeschreibung-->
	<!-- *******************************************************-->
	<xsl:template match="Produktbeschreibung|MaschinenBogen">
		<xsl:apply-templates select="./BlockTitel"/>
		<xsl:call-template name="return"/>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="*[not(name(.)='BlockTitel')]">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="name(.)"/>:
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="."/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Komponente-->
	<!-- *******************************************************-->
	<xsl:template match="Komponente">
	<xsl:call-template name="return"/>
	<xsl:call-template name="return"/>
		<xsl:for-each select=".">
		<!--<xsl:apply-templates select="./BlockTitel"/>-->
		<fo:block text-decoration="underline" font-size="12pt" font-weight="bold">
			<xsl:value-of select="./BlockTitel"></xsl:value-of>
		</fo:block>
		<xsl:apply-templates select="./Parameter"/>
		<xsl:apply-templates select="./Bogeneinteilung"/>
		<xsl:apply-templates select="./Arbeitsvorgaenge"/>
		<xsl:apply-templates select="./Materialien"/>
		<xsl:apply-templates select="./Fremdarbeiten"/>
		<xsl:apply-templates select="./Summen"/>
</xsl:for-each>	
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Zuschussbogen-->
	<!-- *******************************************************-->
	<xsl:template match="Zuschussbogen">
	<xsl:for-each select="./Komponenten/*">
	<xsl:for-each select=".">
	<fo:block>
			<xsl:apply-templates select="./Titel"/>
	</fo:block>
		<fo:table table-layout="fixed" border-after-style="solid" border-width="1pt">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
														<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1.2)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(0.9)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(0.5)"/>
			<fo:table-column column-number="5" column-width="proportional-column-width(0.5)"/>
			<fo:table-column column-number="6" column-width="proportional-column-width(0.8)"/>
			<fo:table-column column-number="7" column-width="proportional-column-width(1)"/>
			
			<fo:table-header>
				<fo:table-row>
					<xsl:for-each select="//Zuschussbogen/titel/*">
						<fo:table-cell background-color="lightgray"
						 border-bottom-style="solid" border-bottom-width="1.0pt" padding-top="2pt">
							<fo:block text-align="start" font-size="9pt">
								<xsl:if test="position()=4 or position()=5">
									<xsl:attribute name="text-align">end</xsl:attribute>
									<xsl:attribute name="end-indent">5pt</xsl:attribute>
								</xsl:if>
								<xsl:if test="position()=6">
									<xsl:attribute name="text-align">end</xsl:attribute>
									<xsl:attribute name="end-indent">10pt</xsl:attribute>
								</xsl:if>
								<xsl:if test="position()=7">
									<xsl:attribute name="text-align">end</xsl:attribute>
									<xsl:attribute name="end-indent">3pt</xsl:attribute>
								</xsl:if>

								<xsl:value-of select="."/>
							</fo:block>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="./Zuschuss">
					<fo:table-row>
						<xsl:for-each select="*">
							<fo:table-cell padding-end="5pt" padding-top="2pt">
								<fo:block text-align="start" font-size="9pt">
									<xsl:if test="name(.)='Nummer'  or name(.)='netto'">
										<xsl:attribute name="text-align">end</xsl:attribute>
									</xsl:if>
									<xsl:if test="name(.)='Zuschuss'">
										<xsl:attribute name="text-align">end</xsl:attribute>
										<xsl:attribute name="end-indent">2pt</xsl:attribute>
									</xsl:if>
									<xsl:if test="name(.)='Format'">
										<xsl:attribute name="text-align">end</xsl:attribute>
										<xsl:attribute name="end-indent">3pt</xsl:attribute>
									</xsl:if>

									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<xsl:call-template name="return"/>
		</xsl:for-each>
		</xsl:for-each>
	</xsl:template>
	
	<!-- ************Arbeitsvorgang****************************-->
	<xsl:template match="Arbeitsvorgaenge">
	<xsl:call-template name="return"/>
	<xsl:call-template name="return"/>
		<xsl:apply-templates select="./BlockTitel"/>		
			<xsl:for-each select="./*[not(name(.)='BlockTitel' or name(.)='Avg-Summe')]">
				<fo:block> 
					<xsl:value-of select="name(.)"/>
				</fo:block>
				<xsl:choose>
					<xsl:when test="count(./titel/key)=10">
						<xsl:call-template name="tabelleZehn"/>
					</xsl:when>
					<xsl:when test="count(./titel/*)=9">
						<xsl:call-template name="tabelle9"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="tabelle8"/>
					</xsl:otherwise>
     				  </xsl:choose>
     		  </xsl:for-each>
       	</xsl:template>
	<!-- *******************************************************-->
	<!-- *******************************************************-->
	<!--Template  für Arbeitsvorgänge mit Zeit mit Kosten-->
	<!-- *******************************************************-->
	 <xsl:template name="tabelleZehn">
				<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.7)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(2.1)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(1.1)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(0.6)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(0.8)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1.1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(1.1)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="9" column-width="proportional-column-width(0.6)"/>
				<fo:table-column column-number="10" column-width="proportional-column-width(1)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
							<fo:table-cell background-color="lightgray" border-bottom-style="solid" 
							border-bottom-width="1.0pt" padding-top="2pt" padding-bottom="2pt"
							 border-left="1pt solid gray">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=10 or position()=9">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
										</xsl:if>
									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<!--  Pro ArbeitsVorgang eine Zeile- - - - - - - - - -  -->
					<xsl:for-each select="./Arbeitsvorgang">
						<fo:table-row>
							<xsl:for-each select="*">
								<fo:table-cell text-align="start" padding-top="2pt" padding-bottom="2pt"
								border-left="1pt solid lightgray">
									<fo:block font-size="8pt">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
										</xsl:if>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
					<xsl:for-each select="./Avg-Summe">
						<fo:table-row>
							<xsl:for-each select="*[not(name(.)='AVG' or name(.)='Arbeitsplatz') ] ">
								<fo:table-cell text-align="start"  border-top-style="solid" 
								border-top-width="1.0pt" padding-top="5pt" padding-bottom="7pt">

																	<xsl:if test="name(.)='Anzahl' ">
										<xsl:attribute name="number-columns-spanned">3</xsl:attribute>
									</xsl:if>
									<fo:block font-size="8pt" font-weight="bold">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
										</xsl:if>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		<!--</xsl:for-each>-->
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Arbeitsvorgänge ohne Zeit mit Kosten-->
	<!-- *******************************************************-->
	<xsl:template name="tabelle9">
				<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.7)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(2.1)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(0.8)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(0.8)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1.1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(0.9)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="9" column-width="proportional-column-width(0.8)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
							<fo:table-cell background-color="lightgray" border-bottom-style="solid" 
							border-bottom-width="1.0pt" padding-top="2pt" padding-bottom="2pt" border-left="1pt solid gray">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=9 or position()=8">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
										</xsl:if>
									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<!--  Pro ArbeitsVorgang eine Zeile- - - - - - - - - -  -->
					<xsl:for-each select="./Arbeitsvorgang">
						<fo:table-row>
							<xsl:for-each select="*">
								<fo:table-cell text-align="start" padding-top="2pt" padding-bottom="2pt" border-left="1pt solid lightgray">
									<fo:block font-size="8pt">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>	
										</xsl:if>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
					<xsl:for-each select="./Avg-Summe">
						<fo:table-row>
							<xsl:for-each select="*[not(name(.)='AVG' or name(.)='Arbeitsplatz') ] ">
								<fo:table-cell text-align="start"  border-top-style="solid" 
								border-top-width="1pt" padding-top="5pt" padding-bottom="7pt">
									<xsl:if test="name(.)='Anzahl' ">
										<xsl:attribute name="number-columns-spanned">3</xsl:attribute>
									</xsl:if>
									<fo:block font-size="8pt" font-weight="bold">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>	
										</xsl:if>
											<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		<!--</xsl:for-each>-->
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Arbeitsvorgänge ohne Zeit mit Kosten-->
	<!-- *******************************************************-->
	<xsl:template name="tabelle8">
				<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(0.7)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(2.3)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(0.8)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(0.8)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1.1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(0.9)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(1.1)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
							<fo:table-cell background-color="lightgray" border-bottom-style="solid" 
							border-bottom-width="1.0pt" padding-top="2pt" padding-bottom="2pt" border-left="1pt solid gray">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=8 or position()=7">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>

										</xsl:if>
									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<!--  Pro ArbeitsVorgang eine Zeile- - - - - - - - - -  -->
					<xsl:for-each select="./Arbeitsvorgang">
						<fo:table-row>
							<xsl:for-each select="*">
								<fo:table-cell text-align="start" padding-top="2pt" padding-bottom="2pt" border-left="1pt solid lightgray">
									<fo:block font-size="8pt">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>	
										</xsl:if>

										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
					
					<!--AVG-Summe-->
					
					<xsl:for-each select="./Avg-Summe">
						<fo:table-row>
							<xsl:for-each select="*[not(name(.)='AVG' or name(.)='Arbeitsplatz') ] ">
								<fo:table-cell text-align="start"  border-top-style="solid" 
								border-top-width="1pt" padding-top="5pt" padding-bottom="7pt">
									<xsl:if test="name(.)='Anzahl' ">
										<xsl:attribute name="number-columns-spanned">3</xsl:attribute>
									</xsl:if>
									<fo:block font-size="8pt" font-weight="bold">
										<xsl:if test="name(.)='Summe'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
										</xsl:if>
										<xsl:if test="name(.)='hh-mm'">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>	
										</xsl:if>
											<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
				<!--AVG-Summe-->
				</fo:table-body>
			</fo:table>
		<!--</xsl:for-each>-->
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  Parameter-->
	<!-- *******************************************************-->
	<xsl:template match="Parameter">
		<fo:block>
			<xsl:apply-templates select="./BlockTitel"/>
			<xsl:apply-templates select="./ProduktParameter"/>
			<xsl:apply-templates select="./Produkteingaben"/>
			<xsl:apply-templates select="./Farbeingaben"/>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für ProduktParameter-->
	<!-- *******************************************************-->
	<xsl:template match="ProduktParameter">
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="*">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
							<xsl:if test="string-length(.) > 0">
								<xsl:value-of select="name(.)"/>:  
								</xsl:if>   
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="."/>
							</fo:block>
							</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<xsl:call-template name="return"/>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für  Farben-->
	<!-- *******************************************************-->
	<xsl:template match="Farbeingaben">
		<xsl:apply-templates select="./BlockTitel"/>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="./*[not(name(.)='BlockTitel')]">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="./key"/>
							</fo:block>
						</fo:table-cell>
						<xsl:for-each select="./value">
							<xsl:if test="position() &lt;= 6">
								<fo:table-cell>
									<fo:block>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
						</xsl:for-each>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<xsl:call-template name="return"/>
		<xsl:if test="count(./Blätter/*) &gt;= 6">
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
				
				<fo:table-body>
					<xsl:for-each select="./*[not(name(.)='BlockTitel')]">
						<fo:table-row>
							<fo:table-cell>
								<fo:block>
									<xsl:value-of select="./key"/>
								</fo:block>
							</fo:table-cell>
							<xsl:for-each select="./value">
								<xsl:if test="position() &gt;= 6">
									<fo:table-cell>
										<fo:block>
											<xsl:value-of select="."/>
										</fo:block>
									</fo:table-cell>
								</xsl:if>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:call-template name="return"/>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Produkteingaben-->
	<!-- *******************************************************-->
	 <xsl:template match="Produkteingaben">
	 	<xsl:apply-templates select="./BlockTitel"/>	 
	 </xsl:template>
	<!-- *******************************************************-->
	<!--Template  Tabelle 1*x-->
	<!-- *******************************************************-->
	<!-- <xsl:template match="Produkteingaben">
		<xsl:call-template name="return"/>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
			<fo:table-body>
				<xsl:for-each select="//Blattbeschreibung/*">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="key"/>
							</fo:block>
						</fo:table-cell>
						<xsl:for-each select="value">
							<xsl:if test="position() &lt;= 6">
								<fo:table-cell>
									<fo:block>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
						</xsl:for-each>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<xsl:if test="count(//Blattbeschreibung/Blätter/*) &gt;= 6">
			<xsl:call-template name="return"/>
			<fo:table table-layout="fixed">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(2)"/>
				<fo:table-body>
					<xsl:for-each select="//Blattbeschreibung/*">
						<fo:table-row>
							<fo:table-cell>
								<fo:block>
									<xsl:value-of select="key"/>
								</fo:block>
							</fo:table-cell>
							<xsl:for-each select="value">
								<xsl:if test="position() &gt;= 6">
									<fo:table-cell>
										<fo:block>
											<xsl:value-of select="."/>
										</fo:block>
									</fo:table-cell>
								</xsl:if>
							</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:call-template name="return"/>
	</xsl:template>-->
	<!-- *******************************************************-->
	<!--Template  für Zeile mit Umbruch-->
	<!-- *******************************************************-->
	<xsl:template match="Titel|BlockTitel">
		<fo:block font-weight="bold" font-size="12pt">
			<xsl:call-template name="return"/>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Text-->
	<!-- *******************************************************-->
	<xsl:template name="Format">
		<fo:table-cell>
			<fo:block>
				<xsl:value-of select="name(.)"/>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell>
			<fo:block>
				<xsl:value-of select="."/>
			</fo:block>
		</fo:table-cell>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für Tabelle mit 2 Spalten Positionsbeschreibung-->
	<!-- *******************************************************-->
	<xsl:template match="Bogeneinteilung">
		<xsl:apply-templates select="./BlockTitel"/>
		<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-column column-number="2" column-width="proportional-column-width(0.7)"/>
			<fo:table-column column-number="3" column-width="proportional-column-width(0.7)"/>
			<fo:table-column column-number="4" column-width="proportional-column-width(0.6)"/>
			<fo:table-body>
				<xsl:for-each select="*">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
									<xsl:value-of select="./key"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
									<xsl:value-of select="./value[1]"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
									<xsl:value-of select="./value[2]"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
									<xsl:value-of select="./value[3]"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template fur return-->
	<!-- *******************************************************-->
	<xsl:template name="return">
		<fo:block>
			<xsl:attribute name="space-before.optimum"><xsl:value-of select="$freeline"/></xsl:attribute>
		</fo:block>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template fur return-->
	<!-- *******************************************************-->
	<xsl:template name="make-line">
		<fo:block>
			<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-body>
				<fo:table-row height="10pt">
					<fo:table-cell border-top="2pt solid black" padding-top="15pt">
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		</fo:block>
	</xsl:template>

	<!-- *******************************************************-->
	<!--Template make-tab-line-->
	<!-- *******************************************************-->
	<xsl:template name="make-tab-line">
		
			<fo:table table-layout="fixed">
			<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
			<xsl:value-of select="$masse"/></xsl:attribute>
			<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell border-top="1pt solid black">
						<fo:block/>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<!-- *******************************************************-->
	<!--Template  für  Fremdarbeiten -->
	<!-- *******************************************************-->
	<xsl:template match="Fremdarbeiten">
		<xsl:apply-templates select="./BlockTitel"/>
		<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(2)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
							<fo:table-cell background-color="lightgray" border-bottom="1pt solid black"
													 border-left="1pt solid gray" padding-top="2pt"
													  padding-bottom="2pt">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=last()">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>

									</xsl:if>
									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
				<fo:table-row>
					<xsl:for-each select="fremdkosten/*">
						<fo:table-cell padding-top="2pt" border-left="1pt solid gray">
						<xsl:if test="position()=5">
							<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
						</xsl:if>
							<fo:block font-size="8pt">
								<xsl:value-of select="."></xsl:value-of>
							</fo:block>
						</fo:table-cell>
					</xsl:for-each>
					</fo:table-row>
					<fo:table-row>
					<fo:table-cell number-columns-spanned="2" border-top="1pt solid black" padding-top="3pt">
						<fo:block font-size="8pt" font-weight="bold">Summe Fremdarbeiten:</fo:block>
					</fo:table-cell>
						<fo:table-cell number-columns-spanned="3" border-top="1pt solid black" padding-top="3pt">
							<fo:block font-size="8pt" font-weight="bold" text-align="end" end-indent="2pt"
							font-family="Courier">
								<xsl:value-of select="summe/Summe"></xsl:value-of>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>

				</fo:table-body>
			</fo:table>
	</xsl:template>
		<!-- *******************************************************-->
	<!--Template  für Materialien __*__ -->
	<!-- *******************************************************-->
		
	<!-- ************Materialien****************************-->
	<xsl:template match="Materialien">
		<xsl:call-template name="return"/>
		<xsl:apply-templates select="./BlockTitel"/>		
			<xsl:for-each select="./*[not(name(.)='BlockTitel' or name(.)='Avg-Summe')]">
				<fo:block> 
					<xsl:value-of select="name(.)"/>
				</fo:block>
				<xsl:choose>
					<xsl:when test="count(./titel/key)=9">
						<xsl:call-template name="Materialien9"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="Materialien8"/>
					</xsl:otherwise>
     				  </xsl:choose>
     		  </xsl:for-each>
       	</xsl:template>

<!-- *******************************************************-->
	<xsl:template name="Materialien9">
			<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1.4)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(3)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(2)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1.3)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(0.1)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(1.7)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(2.5)"/>
				<fo:table-column column-number="9" column-width="proportional-column-width(1.3)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
						<xsl:if test="position()=6">
									<fo:table-cell background-color="lightgray" border-bottom="1pt solid black"
													padding-top="2pt" padding-bottom="2pt">
								<fo:block/>
							</fo:table-cell>
						</xsl:if>
						<xsl:if test="position()!=6">
								<fo:table-cell background-color="lightgray" border-bottom="1pt solid black"
													 border-left="1pt solid gray" padding-top="2pt" padding-bottom="2pt">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=last()">
										<xsl:attribute name="text-align">end</xsl:attribute>
										<xsl:attribute name="end-indent">3pt</xsl:attribute>
										</xsl:if>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
					</xsl:if>
							
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
				<xsl:apply-templates select="./Material"/>
				<xsl:apply-templates select="./Material-Summe"/>
			</fo:table-body>
		</fo:table>
	
	</xsl:template>
	<!-- *******************************************************-->
	<!-- *******************************************************-->
	<xsl:template name="Materialien8">
			<fo:table table-layout="fixed" padding-after="12pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/></xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1.4)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(1.5)"/>
				<fo:table-column column-number="3" column-width="proportional-column-width(3)"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(2)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1.3)"/>
				<fo:table-column column-number="6" column-width="proportional-column-width(1.3)"/>
				<fo:table-column column-number="7" column-width="proportional-column-width(1.7)"/>
				<fo:table-column column-number="8" column-width="proportional-column-width(2)"/>
				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="./titel/*">
							<fo:table-cell background-color="lightgray" border-bottom="1pt solid black"
													 border-left="1pt solid gray" padding-top="2pt"
													  padding-bottom="2pt">
								<fo:block text-align="start" font-size="8pt">
									<xsl:if test="position()=last()">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
									</xsl:if>
									<xsl:value-of select="."/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
				<xsl:apply-templates select="./Material"/>
			</fo:table-body>
		</fo:table>
	
	</xsl:template>

	<!-- *******************************************************-->
	<!-- *******************************************************-->
	<xsl:template match="Material">
	<xsl:for-each select=".">
						<fo:table-row>
								<xsl:for-each select="./*">
								<xsl:if test="name(.)='Anzahl'">
									<fo:table-cell padding-after="2pt" padding-top="2pt"
									 border-bottom="1pt solid black">
										<fo:block font-size="8pt"></fo:block>
									</fo:table-cell>
								</xsl:if>
								<xsl:if test="name(.)!='Anzahl'">
									<fo:table-cell padding-after="2pt" padding-top="2pt"
									 border-bottom="1pt solid black" border-left="1pt solid lightgray">
										<fo:block font-size="8pt">
										<xsl:if test="position()=last()">
											<xsl:attribute name="text-align">end</xsl:attribute>
											<xsl:attribute name="end-indent">3pt</xsl:attribute>
											<xsl:attribute name="font-family">Courier</xsl:attribute>
											<xsl:attribute name="font-weight">bold</xsl:attribute>
											</xsl:if>
											<xsl:value-of select="."/>
										</fo:block>
									</fo:table-cell>
										</xsl:if>
								</xsl:for-each>
						</fo:table-row>
					</xsl:for-each>	
		</xsl:template>
		<!-- *******************************************************-->
	<!-- *******************************************************-->
	<!-- *******************************************************-->
	<xsl:template match="Material-Summe">
	<xsl:for-each select=".">
			<fo:table-row>
			<xsl:for-each select="./*">
				<xsl:if test="position()=1">
					<fo:table-cell number-columns-spanned="3" padding-top="5pt" padding-bottom="7pt"
														 border-before-style="solid" border-before-width="1pt">
							<fo:block text-align="start" font-size="8pt" font-weight="bold">
								<xsl:value-of select="."/>
							</fo:block>
					</fo:table-cell>
				</xsl:if>
				<xsl:if test="position()=last()">
					<fo:table-cell padding-top="5pt" padding-bottom="7pt"
														 border-before-style="solid" border-before-width="1pt">
								<fo:block text-align="end" font-size="8pt" font-weight="bold" 
								font-family="Courier" end-indent="3pt">
								<xsl:value-of select="."/>
							</fo:block>
					</fo:table-cell>
				</xsl:if>
				<xsl:if test="position()>3">
					<fo:table-cell padding-top="7pt" padding-bottom="7pt"  border-before-style="solid"
																				 border-before-width="1pt">
						<fo:block font-size="9pt" font-weight="bold" font-family="Courier" end-indent="3pt">
					
							<xsl:value-of select="."/>
						
						</fo:block>
					</fo:table-cell>
				</xsl:if>
			</xsl:for-each> 
		</fo:table-row>
	</xsl:for-each>	
		</xsl:template>
	<!-- *******************************************************-->
		<xsl:template match="Summen">
		<fo:block font-size="9pt" font-weight="bold">
		<xsl:value-of select="./BlockTitel"/>
		</fo:block>
			<fo:table table-layout="fixed" padding-top="5pt">
				<xsl:attribute name="inline-progression-dimension"><xsl:value-of select="($normBreite)"/>
				<xsl:value-of select="$masse"/>
				</xsl:attribute>
				<fo:table-column column-number="1" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="2" column-width="proportional-column-width(1)"/>
		<fo:table-body>
				<xsl:for-each select="*[not(name(.)='BlockTitel')]">
					<fo:table-row>
						<fo:table-cell padding-after="2pt" padding-top="3pt"
						 border-after-width="1pt" border-after-style="solid">
							<fo:block text-align="start" font-weight="bold" font-size="8pt">
								<xsl:value-of select="name(.)"/>:
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding-after="2pt" padding-top="2pt"
						 border-after-width="1pt" border-after-style="solid">
							<fo:block text-align="end" end-indent="2pt"  font-weight="bold"
							 font-size="8pt" font-family="Courier">
								<xsl:value-of select="."/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		</xsl:template>

	<!--  ################ I n c l u d e ###############-->
	<!-- <xsl:include href="import.xsl"/>-->
	<!--  ################ I n c l u d e ###############-->
</xsl:stylesheet>
